@@ -1,8 +1,8 @@
-if (skip_on_cran()) {
+if (!testthat:::on_cran()) {
   context("Testing Discord function")
 
   w <- 50
-  data <- mp_gait_data
+  data <- tsmp::mp_gait_data
   mp <- tsmp(data, window_size = w, exclusion_zone = 1 / 4, verbose = 0)
   mp <- find_discord(mp)
 
